OC.L10N.register(
    "bookmarks",
    {
    "Details" : "รายละเอียด",
    "Rename" : "เปลี่ยนชื่อ",
    "Move" : "Move",
    "Delete" : "ลบ",
    "New" : "ใหม่",
    "New folder" : "โฟลเดอร์ใหม่",
    "Grid view" : "มุมมองแบบตาราง Grid",
    "List view" : "มุมมองแบบแสดงรายการ",
    "Select all" : "เลือกทั้งหมด",
    "Cancel" : "ยกเลิก",
    "Import" : "นำเข้า",
    "Export" : "ส่งออก",
    "Alphabetically" : "เรียงตามตัวอักษร",
    "Title" : "ชื่อเรื่อง",
    "Link" : "ลิงค์",
    "Tags" : "ป้ายกำกับ",
    "Notes" : "บันทึกย่อ",
    "Owner" : "Owner",
    "Sharing" : "แชร์ข้อมูล",
    "Share link" : "แชร์ลิงค์",
    "Copy link" : "คัดลอกลิงค์",
    "Allow editing" : "อนุญาตให้แก้ไข",
    "Select" : "Select",
    "Folder" : "แฟ้มเอกสาร",
    "Save" : "บันทึก"
},
"nplurals=1; plural=0;");
